@@ -22,6 +22,7 @@ import os
 from copy import copy
 from datetime import timedelta
 from obspy import UTCDateTime
+from obspy import Trace
 from abc import ABCMeta
 from abc import abstractmethod
 
@@ -30,20 +31,22 @@ class Archive(metaclass=ABCMeta):
     """Base class for the different structures an archive can have"""
 
     @abstractmethod
-    def __init__(self, root, experiment, strictcheck):
+    def __init__(self, root: str, experiment: str, strictcheck: bool):
         """Define the root directory where files should be archived and
         whether the archival process should strictly check a coherency in
         the order of the records.
 
         :param root: Directory where files should be archived
         :type root: str
+        :param experiment: Initial and common part of the filenames
+        :type experiment: str
         :param strictcheck: Flag declaring whether to check that this chunk can be appended in case of existing data
         :type strictcheck: bool
         """
         pass
 
     @abstractmethod
-    def archive(self, trace):
+    def archive(self, trace: Trace):
         """Archive mseed
 
         :param trace: Trace to archive
@@ -57,14 +60,14 @@ class StreamBasedHour(Archive):
 
     Output file should not contain GAPS"""
 
-    def __init__(self, root='.', experiment=None, strictcheck=True):
+    def __init__(self, root: str = '.', experiment: str = None, strictcheck: bool = True):
         """Define the root directory where files should be archived and
         whether the archival process should strictly check a coherency in
         the order of the records.
 
         :param root: Directory where files should be archived
         :type root: str
-        :param experiment: Name of the experiment
+        :param experiment: Initial and common part of the filenames
         :type experiment: str
         :param strictcheck: Flag declaring whether to check that this chunk can be appended in case of existing data
         :type strictcheck: bool
@@ -74,7 +77,7 @@ class StreamBasedHour(Archive):
         self.__strictcheck = strictcheck
         self.__add2files = set()
 
-    def archive(self, trace):
+    def archive(self, trace: Trace):
         """Archive mseed
 
         :param trace: Trace to archive
@@ -138,13 +141,15 @@ class StreamBased(Archive):
 
     GAPS will not be removed from the output file"""
 
-    def __init__(self, root='.', experiment=None, strictcheck=True):
+    def __init__(self, root: str = '.', experiment: str = None, strictcheck: bool = True):
         """Define the root directory where files should be archived and
         whether the archival process should strictly check a coherency in
         the order of the records.
 
         :param root: Directory where files should be archived
         :type root: str
+        :param experiment: Initial and common part of the filenames
+        :type experiment: str
         :param strictcheck: Flag declaring whether to check that this chunk can be appended in case of existing data
         :type strictcheck: bool
         """
@@ -154,7 +159,7 @@ class StreamBased(Archive):
         self.__add2files = set()
         self.__uniquestart = None
 
-    def archive(self, trace):
+    def archive(self, trace: Trace):
         """Archive mseed
 
         :param trace: Trace to archive
@@ -202,7 +207,7 @@ class StreamBased(Archive):
 
 class SDS(Archive):
     """Class to archive miniSEED in an SDS structure"""
-    def __init__(self, root='.', experiment=None, strictcheck=True):
+    def __init__(self, root: str = '.', experiment: str = None, strictcheck: bool = True):
         """Define the root directory of the SDS structure
 
         The structure is defined as
@@ -210,6 +215,8 @@ class SDS(Archive):
 
         :param root: Root directory of the SDS structure
         :type root: str
+        :param experiment: Initial and common part of the filenames
+        :type experiment: str
         :param strictcheck: Flag to declare if the miniSEED chunk should always be parsed to check proper directory structure
         :type strictcheck: bool
         """
@@ -219,7 +226,7 @@ class SDS(Archive):
         if strictcheck:
             logging.warning('Strict Check was not implemented in SDS class')
 
-    def archive(self, trace):
+    def archive(self, trace: Trace):
         """Archive mseed
 
         :param trace: Trace to archive
@@ -279,7 +286,8 @@ class SDS(Archive):
                 daytrace = trace.slice(starttime=auxstart,
                                        endtime=auxend,
                                        nearest_sample=False)
-                daytrace.write(fout, format='MSEED', reclen=512)
+                # Save always in BigEndian order
+                daytrace.write(fout, format='MSEED', byteorder='>')
 
             # Move to the next day
             auxstart = copy(auxend)
